OpenCyc for the Semantic Web
============================

From the `OpenCyc`_ web site:

  Now it is even easier to use the rich and diverse collection of
  real-world concepts in OpenCyc_ to bring meaning to your semantic
  web applications! The full OpenCyc content is now available both
  as downloadable OWL ontologies as well as via semantic web endpoints
  (i.e., permanent URIs). These URIs return RDF representations of
  each Cyc concept as well as a human-readable version when accessed
  via a Web Browser.

.. automodule:: ordf.vocab.opencyc